==> struts-2.5.33-src.zip: struts-2.5.33/src/core/src/test/java/com/opensymphony/xwork2/ValidationOrderAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.opensymphony.xwork2;

/**
 * A sample action to test validation order.
 * 
 * @author tm_jee
 * @version $Date$ $Id$
 */
public class ValidationOrderAction extends ActionSupport {
	
	private String username;
	private String password;
	private String confirmPassword;
	private String firstName;
	private String lastName;
	private String city;
	private String province;
	private String country;
	private String postalCode;
	private String email;
	private String website;
	private String passwordHint;
	
	
	
	@Override
    public String execute() throws Exception {
		return SUCCESS;
	}



	public String getCity() {
		return city;
	}



	public void setCity(String city) {
		this.city = city;
	}



	public String getConfirmPassword() {
		return confirmPassword;
	}



	public void setConfirmPassword(String confirmPassword) {
		this.confirmPassword = confirmPassword;
	}



	public String getCountry() {
		return country;
	}



	public void setCountry(String country) {
		this.country = country;
	}



	public String getEmail() {
		return email;
	}



	public void setEmail(String email) {
		this.email = email;
	}



	public String getFirstName() {
		return firstName;
	}



	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}



	public String getLastName() {
		return lastName;
	}



	public void setLastName(String lastName) {
		this.lastName = lastName;
	}



	public String getPassword() {
		return password;
	}



	public void setPassword(String password) {
		this.password = password;
	}



	public String getPasswordHint() {
		return passwordHint;
	}



	public void setPasswordHint(String passwordHint) {
		this.passwordHint = passwordHint;
	}



	public String getPostalCode() {
		return postalCode;
	}



	public void setPostalCode(String postalCode) {
		this.postalCode = postalCode;
	}



	public String getProvince() {
		return province;
	}



	public void setProvince(String province) {
		this.province = province;
	}



	public String getUsername() {
		return username;
	}



	public void setUsername(String username) {
		this.username = username;
	}



	public String getWebsite() {
		return website;
	}



	public void setWebsite(String website) {
		this.website = website;
	}
}

==> struts-6.8.0-src.zip: struts-6.8.0/src/core/src/test/java/com/opensymphony/xwork2/ValidationOrderAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.opensymphony.xwork2;

import org.apache.struts2.interceptor.parameter.StrutsParameter;

/**
 * A sample action to test validation order.
 *
 * @author tm_jee
 * @version $Date$ $Id$
 */
public class ValidationOrderAction extends ActionSupport {

	private String username;
	private String password;
	private String confirmPassword;
	private String firstName;
	private String lastName;
	private String city;
	private String province;
	private String country;
	private String postalCode;
	private String email;
	private String website;
	private String passwordHint;



	@Override
    public String execute() throws Exception {
		return SUCCESS;
	}



	public String getCity() {
		return city;
	}


	@StrutsParameter
	public void setCity(String city) {
		this.city = city;
	}



	public String getConfirmPassword() {
		return confirmPassword;
	}


	@StrutsParameter
	public void setConfirmPassword(String confirmPassword) {
		this.confirmPassword = confirmPassword;
	}



	public String getCountry() {
		return country;
	}


	@StrutsParameter
	public void setCountry(String country) {
		this.country = country;
	}



	public String getEmail() {
		return email;
	}


	@StrutsParameter
	public void setEmail(String email) {
		this.email = email;
	}



	public String getFirstName() {
		return firstName;
	}


	@StrutsParameter
	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}



	public String getLastName() {
		return lastName;
	}


	@StrutsParameter
	public void setLastName(String lastName) {
		this.lastName = lastName;
	}



	public String getPassword() {
		return password;
	}


	@StrutsParameter
	public void setPassword(String password) {
		this.password = password;
	}



	public String getPasswordHint() {
		return passwordHint;
	}


	@StrutsParameter
	public void setPasswordHint(String passwordHint) {
		this.passwordHint = passwordHint;
	}



	public String getPostalCode() {
		return postalCode;
	}


	@StrutsParameter
	public void setPostalCode(String postalCode) {
		this.postalCode = postalCode;
	}



	public String getProvince() {
		return province;
	}


	@StrutsParameter
	public void setProvince(String province) {
		this.province = province;
	}



	public String getUsername() {
		return username;
	}


	@StrutsParameter
	public void setUsername(String username) {
		this.username = username;
	}



	public String getWebsite() {
		return website;
	}


	@StrutsParameter
	public void setWebsite(String website) {
		this.website = website;
	}
}
